@@ -3,7 +3,8 @@
 ;; Copyright (C) 2023 Free Software Foundation, Inc.
 
 ;; Author: Karthik Chikmagalur <karthik.chikmagalur@gmail.com>
-;; Version: 0.4.8
+;; Package-Version: 20260302.22
+;; Package-Revision: d83b894ee7a9
 ;; Package-Requires: ((emacs "26.1"))
 ;; Keywords: convenience
 ;; URL: https://github.com/karthink/popper
@@ -311,7 +312,7 @@ This is intended to be used in `display-buffer-alist'."
 The project root is used if found by project, with the default
 directory as a fall back."
   (or (and (fboundp 'project-root)
-           (when-let ((project (project-current)))
+           (when-let* ((project (project-current)))
              (project-root project)))
       (expand-file-name default-directory)))
 
@@ -321,7 +322,7 @@ directory as a fall back."
     (user-error "Cannot find project directory to group popups. \
 Please install `project' or customize \
 `popper-group-function'"))
-  (when-let ((project (project-current)))
+  (when-let* ((project (project-current)))
     (project-root project)))
 
 (defun popper-group-by-projectile ()
@@ -475,9 +476,6 @@ a popup buffer to open."
   (when (window-valid-p win)
     (cond
      ((window-parent win)
-      ;; FIXME Possibly a bad idea to mess with atomic windows
-      (when (window-parameter win 'window-atom)
-        (set-window-parameter win 'window-atom nil))
       ;; Kludge. Side windows and regular windows are handled differently. The
       ;; latter is still somewhat broken. This is a bad idea.
       (if (window-parameter win 'window-side)
@@ -583,7 +581,7 @@ See `popper-cycle' for NUM and details."
 (defun popper-raise-popup (&optional buffer)
   "Raise a popup to regular status.
 If BUFFER is not specified,raise the current buffer."
-  (when-let ((buf (get-buffer (or buffer (current-buffer)))))
+  (when-let* ((buf (get-buffer (or buffer (current-buffer)))))
     (with-current-buffer buf
       (if (popper-popup-p buf)
           (setq popper-popup-status 'raised)
@@ -596,12 +594,13 @@ If BUFFER is not specified,raise the current buffer."
   "Turn a regular buffer BUFFER into a popup.
 
 If BUFFER is not specified act on the current buffer instead."
-  (let ((buf (get-buffer (or buffer (current-buffer)))))
+  (let* ((buf (get-buffer (or buffer (current-buffer))))
+         (win (get-buffer-window buf t)))
     (with-current-buffer buf
       (setq popper-popup-status (if (popper-popup-p buf)
                                     'popup
                                   'user-popup))
-      (quit-window nil (get-buffer-window buf t))
+      (when win (quit-window nil win))
       (pop-to-buffer buf))
     (popper--update-popups)))
 
@@ -647,7 +646,7 @@ This should run after `popper--update-popups' in
                (with-selected-window win
                  (setq-local popper-popup-status 'popup)
                  ;; If window was previously showing a different buffer, switch to it
-                 (if-let ((wpb (window-prev-buffers win))
+                 (if-let* ((wpb (window-prev-buffers win))
                           (switch-to-buffer-preserve-window-point t))
                      (switch-to-buffer (caar wpb))
                    ;; otherwise kill this window/frame
